==> odps-center-api-1.3.13-20240423.071424-3-sources.jar: cn/com/duiba/odps/center/api/dto/picclife/GxfhActionDto.java <==
package cn.com.duiba.odps.center.api.dto.picclife;

import java.io.Serializable;
import java.util.Date;

/**
 * 多巴胺action
 *
 * @author songp
 * @date 2024/3/14 5:27 下午
 */
public class GxfhActionDto implements Serializable {

    // 自增主键
    private Long id;

    // 日期
    private String curDate;

    // 开发者用户id
    private String userId;

    private String appUserId;

    // 友客业务员code
    private String agentCode;

    // 事件名称
    private String activityType;

    // 事件code
    private String activityCode;

    /**
     * 通关状态(仅三个参与游戏事件有)
     */
    private Long activityState;

    // 事件更新时间
    private String insertTime;


    /**
     * 参与姓名
     */
    private String name;

    /**
     * 联系方式
     */
    private String mobile;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String country;

    /**
     *  区县
     */
    private String city;

    // 创建时间
    private Date gmtCreate;

    // 修改时间
    private Date gmtModified;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCountry() {
        return country;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCurDate() {
        return curDate;
    }

    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getAppUserId() {
        return appUserId;
    }

    public void setAppUserId(String appUserId) {
        this.appUserId = appUserId;
    }

    public String getAgentCode() {
        return agentCode;
    }

    public void setAgentCode(String agentCode) {
        this.agentCode = agentCode;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    public String getActivityCode() {
        return activityCode;
    }

    public void setActivityCode(String activityCode) {
        this.activityCode = activityCode;
    }

    public String getInsertTime() {
        return insertTime;
    }

    public void setInsertTime(String insertTime) {
        this.insertTime = insertTime;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getActivityState() {
        return activityState;
    }

    public void setActivityState(Long activityState) {
        this.activityState = activityState;
    }
}

==> odps-center-api-1.3.30-20241024.020818-2-sources.jar: cn/com/duiba/odps/center/api/dto/picclife/GxfhActionDto.java <==
package cn.com.duiba.odps.center.api.dto.picclife;

import java.io.Serializable;
import java.util.Date;

/**
 * 多巴胺action
 *
 * @author songp
 * @date 2024/3/14 5:27 下午
 */
public class GxfhActionDto implements Serializable {

    private static final long serialVersionUID = -9187798752323515823L;
    // 自增主键
    private Long id;

    // 日期
    private String curDate;

    // 开发者用户id
    private String userId;

    private String appUserId;

    // 友客业务员code
    private String agentCode;

    // 事件名称
    private String activityType;

    // 事件code
    private String activityCode;

    /**
     * 通关状态(仅三个参与游戏事件有)
     */
    private Long activityState;

    /**
     * 积分(仅活动排名事件有值)
     */
    private Long activityShareCount;

    // 事件更新时间
    private String insertTime;


    /**
     * 参与姓名
     */
    private String name;

    /**
     * 联系方式
     */
    private String mobile;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String country;

    /**
     *  区县
     */
    private String city;

    // 创建时间
    private Date gmtCreate;

    // 修改时间
    private Date gmtModified;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCountry() {
        return country;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCurDate() {
        return curDate;
    }

    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getAppUserId() {
        return appUserId;
    }

    public void setAppUserId(String appUserId) {
        this.appUserId = appUserId;
    }

    public String getAgentCode() {
        return agentCode;
    }

    public void setAgentCode(String agentCode) {
        this.agentCode = agentCode;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    public String getActivityCode() {
        return activityCode;
    }

    public void setActivityCode(String activityCode) {
        this.activityCode = activityCode;
    }

    public String getInsertTime() {
        return insertTime;
    }

    public void setInsertTime(String insertTime) {
        this.insertTime = insertTime;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getActivityState() {
        return activityState;
    }

    public void setActivityState(Long activityState) {
        this.activityState = activityState;
    }

    public Long getActivityShareCount() {
        return activityShareCount;
    }

    public void setActivityShareCount(Long activityShareCount) {
        this.activityShareCount = activityShareCount;
    }
}
